summaryrefslogtreecommitdiffstats
path: root/kget/kget_iface.h
diff options
context:
space:
mode:
Diffstat (limited to 'kget/kget_iface.h')
-rw-r--r--kget/kget_iface.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kget/kget_iface.h b/kget/kget_iface.h
index 015bef2f..df01375c 100644
--- a/kget/kget_iface.h
+++ b/kget/kget_iface.h
@@ -16,14 +16,14 @@ class KGetIface : public DCOPObject
K_DCOP
protected:
- KGetIface( QCString objId ) : DCOPObject( objId ) {}
+ KGetIface( TQCString objId ) : DCOPObject( objId ) {}
k_dcop:
/**
* @param src The urls to download
* @param destDir The destination direction or QString::null if unspecified
*/
- virtual ASYNC addTransfers( const KURL::List& src, const QString& destDir = QString::null ) = 0;
+ virtual ASYNC addTransfers( const KURL::List& src, const TQString& destDir = TQString::null ) = 0;
virtual bool isDropTargetVisible() const = 0;
@@ -16,14 +16,14 @@ class KGetIface : public DCOPObject
/**
* @param src The urls to download
- * @param destDir The destination direction or QString::null if unspecified
+ * @param destDir The destination direction or TQString::null if unspecified
*/